==> mesa_20.3.5.orig.tar.gz: mesa-20.3.5/src/freedreno/vulkan/tu_wsi_wayland.c <==
/*
 * Copyright © 2016 Red Hat
 * based on intel anv code:
 * Copyright © 2015 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include "tu_private.h"

#include "wsi_common_wayland.h"

VkBool32
tu_GetPhysicalDeviceWaylandPresentationSupportKHR(
   VkPhysicalDevice physicalDevice,
   uint32_t queueFamilyIndex,
   struct wl_display *display)
{
   TU_FROM_HANDLE(tu_physical_device, physical_device, physicalDevice);

   return wsi_wl_get_presentation_support(&physical_device->wsi_device,
                                          display);
}

VkResult
tu_CreateWaylandSurfaceKHR(VkInstance _instance,
                           const VkWaylandSurfaceCreateInfoKHR *pCreateInfo,
                           const VkAllocationCallbacks *pAllocator,
                           VkSurfaceKHR *pSurface)
{
   TU_FROM_HANDLE(tu_instance, instance, _instance);
   const VkAllocationCallbacks *alloc;
   assert(pCreateInfo->sType ==
          VK_STRUCTURE_TYPE_WAYLAND_SURFACE_CREATE_INFO_KHR);

   if (pAllocator)
      alloc = pAllocator;
   else
      alloc = &instance->alloc;

   return wsi_create_wl_surface(alloc, pCreateInfo, pSurface);
}

==> mesa_21.2.6.orig.tar.gz: mesa-21.2.6/src/freedreno/vulkan/tu_wsi_wayland.c <==
/*
 * Copyright © 2016 Red Hat
 * based on intel anv code:
 * Copyright © 2015 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#include "tu_private.h"

#include "wsi_common_wayland.h"

VKAPI_ATTR VkBool32 VKAPI_CALL
tu_GetPhysicalDeviceWaylandPresentationSupportKHR(
   VkPhysicalDevice physicalDevice,
   uint32_t queueFamilyIndex,
   struct wl_display *display)
{
   TU_FROM_HANDLE(tu_physical_device, physical_device, physicalDevice);

   return wsi_wl_get_presentation_support(&physical_device->wsi_device,
                                          display);
}

VKAPI_ATTR VkResult VKAPI_CALL
tu_CreateWaylandSurfaceKHR(VkInstance _instance,
                           const VkWaylandSurfaceCreateInfoKHR *pCreateInfo,
                           const VkAllocationCallbacks *pAllocator,
                           VkSurfaceKHR *pSurface)
{
   TU_FROM_HANDLE(tu_instance, instance, _instance);
   const VkAllocationCallbacks *alloc;
   assert(pCreateInfo->sType ==
          VK_STRUCTURE_TYPE_WAYLAND_SURFACE_CREATE_INFO_KHR);

   if (pAllocator)
      alloc = pAllocator;
   else
      alloc = &instance->vk.alloc;

   return wsi_create_wl_surface(alloc, pCreateInfo, pSurface);
}
